==> tencentcloud-sdk-java-3.1.97-sources.jar: com/tencentcloudapi/solar/v20181011/models/DescribeResourceTemplateHeadersRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.solar.v20181011.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeResourceTemplateHeadersRequest extends AbstractModel{

    /**
    * 微信公众号appId
    */
    @SerializedName("WxAppId")
    @Expose
    private String WxAppId;

    /**
     * Get 微信公众号appId 
     * @return WxAppId 微信公众号appId
     */
    public String getWxAppId() {
        return this.WxAppId;
    }

    /**
     * Set 微信公众号appId
     * @param WxAppId 微信公众号appId
     */
    public void setWxAppId(String WxAppId) {
        this.WxAppId = WxAppId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "WxAppId", this.WxAppId);

    }
}

==> tencentcloud-sdk-java-3.1.737-sources.jar: com/tencentcloudapi/solar/v20181011/models/DescribeResourceTemplateHeadersRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.solar.v20181011.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeResourceTemplateHeadersRequest extends AbstractModel{

    /**
    * 微信公众号appId
    */
    @SerializedName("WxAppId")
    @Expose
    private String WxAppId;

    /**
     * Get 微信公众号appId 
     * @return WxAppId 微信公众号appId
     */
    public String getWxAppId() {
        return this.WxAppId;
    }

    /**
     * Set 微信公众号appId
     * @param WxAppId 微信公众号appId
     */
    public void setWxAppId(String WxAppId) {
        this.WxAppId = WxAppId;
    }

    public DescribeResourceTemplateHeadersRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeResourceTemplateHeadersRequest(DescribeResourceTemplateHeadersRequest source) {
        if (source.WxAppId != null) {
            this.WxAppId = new String(source.WxAppId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "WxAppId", this.WxAppId);

    }
}
